@@ -30,31 +30,23 @@ for which a new license (GPL+exception) is in place.
 
 #ifdef HAVE_PODOFO
 
-using namespace PoDoFo;
-
-#if (PODOFO_VERSION < PODOFO_MAKE_VERSION(0, 10, 0))
-#define IsRealStrict IsReal
-#endif
-
 #if (PODOFO_VERSION >= PODOFO_MAKE_VERSION(1, 0, 0))
 #include <string_view>
 #include <utility>
 
-namespace std
+namespace PoDoFo
 {
-	template<>
-	struct less<PoDoFo::PdfName>
+	bool operator<(const PdfName& n1, const PdfName& n2)
 	{
-		bool operator()(const PoDoFo::PdfName& n1, const PoDoFo::PdfName& n2) const
-		{
-			std::string_view s1 = n1.GetRawData();
-			std::string_view s2 = n2.GetRawData();
-			return s1 < s2;
-		}
-	};
+		std::string_view s1 = n1.GetRawData();
+		std::string_view s2 = n2.GetRawData();
+		return s1 < s2;
+	}
 }
 #endif
 
+using namespace PoDoFo;
+
 static QHash<QString, PDFContentStreamKeyword> kwNameMap;
 
 // we gonna need a map from string values to the defined enum of pdf keywords
@@ -276,7 +268,11 @@ bool PDFAnalyzer::inspectCanvas(PdfCanvas* canvas, QList<PDFColorSpace> & usedCo
 	try
 	{
 		// start parsing the content stream
+#if (PODOFO_VERSION >= PODOFO_MAKE_VERSION(1, 0, 0))
+		PdfContentReaderArgs tokenizerArgs;
+#else
 		PdfContentReaderArgs tokenizerArgs = { PdfContentReaderFlags::DontFollowXObjectForms };
+#endif
 		PdfContentStreamReader tokenizer(*canvas, tokenizerArgs);
 		PdfContent pdfContent;
 		PdfVariant var;
@@ -289,13 +285,29 @@ bool PDFAnalyzer::inspectCanvas(PdfCanvas* canvas, QList<PDFColorSpace> & usedCo
 		while (tokenizer.TryReadNext(pdfContent))
 		{
 			++tokenNumber;
+#if (PODOFO_VERSION >= PODOFO_MAKE_VERSION(1, 0, 0))
+			if (pdfContent.GetType() == PdfContentType::Operator)
+#else
 			if (pdfContent.Type == PdfContentType::Operator)
+#endif
 			{
 				args.clear();
+#if (PODOFO_VERSION >= PODOFO_MAKE_VERSION(1, 0, 0))
+				const auto& pdfContentStack = pdfContent.GetStack();
+				size_t stackSize = pdfContentStack.size();
+				for (size_t i = 0; i < stackSize; ++i)
+					args.append(pdfContentStack[stackSize - 1 - i]);
+#else
+
 				size_t stackSize = pdfContent.Stack.size();
 				for (size_t i = 0; i < stackSize; ++i)
 					args.append(pdfContent.Stack[stackSize - 1 - i]);
+#endif
+#if (PODOFO_VERSION >= PODOFO_MAKE_VERSION(1, 0, 0))
+				switch (pdfContent.GetOperator())
+#else
 				switch (pdfContent.Operator)
+#endif
 				{
 				case PdfOperator::q:
 					gsStack.push(currGS);
@@ -677,12 +689,23 @@ bool PDFAnalyzer::inspectCanvas(PdfCanvas* canvas, QList<PDFColorSpace> & usedCo
 				}
 				args.clear();
 			}
+#if (PODOFO_VERSION >= PODOFO_MAKE_VERSION(1, 0, 0))
+			if (pdfContent.GetType() == PdfContentType::DoXObject)
+#else
 			if (pdfContent.Type == PdfContentType::DoXObject)
+#endif
 			{
 				args.clear();
+#if (PODOFO_VERSION >= PODOFO_MAKE_VERSION(1, 0, 0))
+				const auto& pdfContentStack = pdfContent.GetStack();
+				size_t stackSize = pdfContentStack.size();
+				for (size_t i = 0; i < stackSize; ++i)
+					args.append(pdfContentStack[stackSize - 1 - i]);
+#else
 				size_t stackSize = pdfContent.Stack.size();
 				for (size_t i = 0; i < stackSize; ++i)
 					args.append(pdfContent.Stack[stackSize - 1 - i]);
+#endif
 				if (!processedNamedXObj.contains(args[0].GetName()))
 				{
 					if (args.size() == 1 && args[0].IsName() && xObjectsDict)
