@@ -16,6 +16,7 @@ for which a new license (GPL+exception) is in place.
 #include <QRegExp>
 #include <QStack>
 #include <QTemporaryFile>
+#include <QUrl>
 
 #include "svgplugin.h"
 
@@ -308,16 +309,24 @@ QImage SVGPlug::readThumbnail(const QString& fName)
 
 bool SVGPlug::import(const QString& fname, const TransactionSettings& trSettings, int flags)
 {
+	m_currentSvgFilePath.clear();
+	m_currentSvgFileDir.clear();
+
 	if (!loadData(fname))
 	{
 		importFailed = true;
 		return false;
 	}
+
+	QFileInfo fInfo(fname);
+	m_currentSvgFilePath = fInfo.absoluteFilePath();
+	m_currentSvgFileDir = fInfo.absolutePath();
+
 	QString CurDirP = QDir::currentPath();
-	QFileInfo efp(fname);
-	QDir::setCurrent(efp.path());
+	QDir::setCurrent(fInfo.path());
 	convert(trSettings, flags);
 	QDir::setCurrent(CurDirP);
+
 	return true;
 }
 
@@ -1600,8 +1609,29 @@ QList<PageItem*> SVGPlug::parseImage(const QDomElement &e)
 	PageItem* ite = m_Doc->Items->at(z);
 	if (!hrefData.isEmpty())
 	{
+		// hrefData contains a filename
 		if (!hrefData.startsWith("data:"))
-			m_Doc->loadPict(hrefData, ite);
+		{
+			// Be a bit careful about where we load from
+			QUrl fileUrl(hrefData);
+			if (fileUrl.isValid())
+			{
+				bool isLocalFile = fileUrl.isLocalFile();
+				QString host = fileUrl.host();
+				if (isLocalFile && host.isEmpty())
+				{
+					QString imageFilePath = fileUrl.toLocalFile();
+					m_Doc->loadPict(imageFilePath, ite);
+				}
+				else if (host.isEmpty())
+				{
+					QString imageFilePath(hrefData);
+					if (fileUrl.isRelative())
+						imageFilePath = m_currentSvgFileDir + "/" + fileUrl.path();
+					m_Doc->loadPict(imageFilePath, ite);
+				}
+			}
+		}
 		else
 		{
 			int startData = hrefData.indexOf(",");
@@ -1611,18 +1641,19 @@ QList<PageItem*> SVGPlug::parseImage(const QDomElement &e)
 			ba.append(hrefData);
 			if (dataType.contains("base64"))
 				ba = QByteArray::fromBase64(ba);
-			QTemporaryFile *tempFile = new QTemporaryFile(QDir::tempPath() + "/scribus_temp_svg_XXXXXX.png");
-			tempFile->setAutoRemove(false);
-			tempFile->open();
-			QString fileName = getLongPathName(tempFile->fileName());
-			tempFile->close();
-			delete tempFile;
-			ite->isTempFile = true;
-			ite->isInlineImage = true;
-			QImage img;
-			img.loadFromData(ba);
-			img.save(fileName, "PNG");
-			m_Doc->loadPict(fileName, ite);
+			QTemporaryFile tempFile(QDir::tempPath() + "/scribus_temp_svg_XXXXXX.png");
+			if (tempFile.open())
+			{
+				QString fileName = getLongPathName(tempFile.fileName());
+				tempFile.setAutoRemove(false);
+				tempFile.close();
+				ite->isTempFile = true;
+				ite->isInlineImage = true;
+				QImage img;
+				img.loadFromData(ba);
+				img.save(fileName, "PNG");
+				m_Doc->loadPict(fileName, ite);
+			}
 		}
 	}
 	if (!clipPath.empty())
