@@ -51,7 +51,7 @@ PyObject *scribus_getpagetype(PyObject* /* self */, PyObject* args)
 	e--;
 	if ((e < 0) || (e > ScCore->primaryMainWindow()->doc->Pages->count() - 1))
 	{
-		PyErr_SetString(PyExc_IndexError, QObject::tr("Page number out of range.","python error").toLocal8Bit().constData());
+		PyErr_SetString(PyExc_IndexError, QObject::tr("Page number out of range.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	return PyLong_FromLong(static_cast<long>(ScCore->primaryMainWindow()->doc->locationOfPage(e)));
@@ -61,7 +61,10 @@ PyObject *scribus_savepageeps(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "es", "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 	QString epsError;
@@ -71,7 +74,7 @@ PyObject *scribus_savepageeps(PyObject* /* self */, PyObject* args)
 		QString message = QObject::tr("Failed to save EPS.","python error");
 		if (!epsError.isEmpty())
 			message += QString("\n%1").arg(epsError);
-		PyErr_SetString(ScribusException, message.toLocal8Bit().constData());
+		PyErr_SetString(ScribusException, message.toUtf8().constData());
 		return nullptr;
 	}
 
@@ -88,7 +91,7 @@ PyObject *scribus_deletepage(PyObject* /* self */, PyObject* args)
 	e--;
 	if ((e < 0) || (e > ScCore->primaryMainWindow()->doc->Pages->count() - 1))
 	{
-		PyErr_SetString(PyExc_IndexError, QObject::tr("Page number out of range.","python error").toLocal8Bit().constData());
+		PyErr_SetString(PyExc_IndexError, QObject::tr("Page number out of range.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	ScCore->primaryMainWindow()->deletePage2(e);
@@ -106,7 +109,7 @@ PyObject *scribus_gotopage(PyObject* /* self */, PyObject* args)
 	e--;
 	if ((e < 0) || (e > ScCore->primaryMainWindow()->doc->Pages->count() - 1))
 	{
-		PyErr_SetString(PyExc_IndexError, QObject::tr("Page number out of range.","python error").toLocal8Bit().constData());
+		PyErr_SetString(PyExc_IndexError, QObject::tr("Page number out of range.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	ScCore->primaryMainWindow()->view->GotoPage(e);
@@ -120,7 +123,10 @@ PyObject *scribus_newpage(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	QString qName(CommonStrings::trMasterPageNormal);
 	if (!PyArg_ParseTuple(args, "i|es", &e, "utf-8", name.ptr()))
+	{
+		name.resetDontFree();
 		return nullptr;
+	}
 	if (!checkHaveDocument())
 		return nullptr;
 
@@ -148,7 +154,7 @@ PyObject *scribus_newpage(PyObject* /* self */, PyObject* args)
 
 	if (!currentDoc->MasterNames.contains(qName))
 	{
-		PyErr_SetString(PyExc_IndexError, QObject::tr("Given master page name does not match any existing.","python error").toLocal8Bit().constData());
+		PyErr_SetString(PyExc_IndexError, QObject::tr("Given master page name does not match any existing.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	if (e < 0)
@@ -158,7 +164,7 @@ PyObject *scribus_newpage(PyObject* /* self */, PyObject* args)
 		e--;
 		if ((e < 0) || (e > loc - 1))
 		{
-			PyErr_SetString(PyExc_IndexError, QObject::tr("Page number out of range.","python error").toLocal8Bit().constData());
+			PyErr_SetString(PyExc_IndexError, QObject::tr("Page number out of range.","python error").toUtf8().constData());
 			return nullptr;
 		}
 		mainWin->slotNewPageP(e, qName);
@@ -244,7 +250,7 @@ PyObject *scribus_getpagensize(PyObject* /* self */, PyObject* args)
 	e--;
 	if ((e < 0) || (e > currentDoc->Pages->count() - 1))
 	{
-		PyErr_SetString(PyExc_IndexError, QObject::tr("Page number out of range.","python error").toLocal8Bit().constData());
+		PyErr_SetString(PyExc_IndexError, QObject::tr("Page number out of range.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	PyObject *t;
@@ -268,7 +274,7 @@ PyObject *scribus_getpagenmargins(PyObject* /* self */, PyObject* args)
 	e--;
 	if ((e < 0) || (e > currentDoc->Pages->count() - 1))
 	{
-		PyErr_SetString(PyExc_IndexError, QObject::tr("Page number out of range.","python error").toLocal8Bit().constData());
+		PyErr_SetString(PyExc_IndexError, QObject::tr("Page number out of range.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	PyObject *margins = nullptr;
@@ -344,7 +350,7 @@ PyObject *scribus_setHguides(PyObject* /* self */, PyObject* args)
 
 	if (!PyList_Check(l))
 	{
-		PyErr_SetString(PyExc_TypeError, QObject::tr("argument is not list: must be list of float values.","python error").toLocal8Bit().constData());
+		PyErr_SetString(PyExc_TypeError, QObject::tr("argument is not list: must be list of float values.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	Py_ssize_t n = PyList_Size(l);
@@ -354,7 +360,7 @@ PyObject *scribus_setHguides(PyObject* /* self */, PyObject* args)
 	{
 		if (!PyArg_Parse(PyList_GetItem(l, i), "d", &guide))
 		{
-			PyErr_SetString(PyExc_TypeError, QObject::tr("argument contains non-numeric values: must be list of float values.","python error").toLocal8Bit().constData());
+			PyErr_SetString(PyExc_TypeError, QObject::tr("argument contains non-numeric values: must be list of float values.","python error").toUtf8().constData());
 			return nullptr;
 		}
 		currentDoc->currentPage()->guides.addHorizontal(ValueToPoint(guide), GuideManagerCore::Standard);
@@ -394,7 +400,7 @@ PyObject *scribus_setVguides(PyObject* /* self */, PyObject* args)
 
 	if (!PyList_Check(l))
 	{
-		PyErr_SetString(PyExc_TypeError, QObject::tr("argument is not list: must be list of float values.","python error").toLocal8Bit().constData());
+		PyErr_SetString(PyExc_TypeError, QObject::tr("argument is not list: must be list of float values.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	Py_ssize_t n = PyList_Size(l);
@@ -404,7 +410,7 @@ PyObject *scribus_setVguides(PyObject* /* self */, PyObject* args)
 	{
 		if (!PyArg_Parse(PyList_GetItem(l, i), "d", &guide))
 		{
-			PyErr_SetString(PyExc_TypeError, QObject::tr("argument contains no-numeric values: must be list of float values.","python error").toLocal8Bit().constData());
+			PyErr_SetString(PyExc_TypeError, QObject::tr("argument contains no-numeric values: must be list of float values.","python error").toUtf8().constData());
 			return nullptr;
 		}
 		currentDoc->currentPage()->guides.addVertical(ValueToPoint(guide), GuideManagerCore::Standard);
@@ -503,7 +509,7 @@ PyObject *scribus_setColumnGuides(PyObject* /* self */, PyObject* args, PyObject
 	if (referTo < 0 || referTo > 2)
 	{
 		QString message = QObject::tr("refer_to=0|1|2.","python error");
-		PyErr_SetString(ScribusException, message.toLocal8Bit().constData());
+		PyErr_SetString(ScribusException, message.toUtf8().constData());
 		return nullptr;
 	}
 	else if (referTo == 2)
@@ -512,7 +518,7 @@ PyObject *scribus_setColumnGuides(PyObject* /* self */, PyObject* args, PyObject
 		if (doc->m_Selection->isEmpty())
 		{
 			QString message = QObject::tr("setColumnGuides() with refer_to=2 needs a selection.","python error");
-			PyErr_SetString(ScribusException, message.toLocal8Bit().constData());
+			PyErr_SetString(ScribusException, message.toUtf8().constData());
 			return nullptr;
 		}
 		doc->currentPage()->guides.resetSelectionForPage(doc->currentPage());
@@ -552,7 +558,7 @@ PyObject *scribus_setRowGuides(PyObject* /* self */, PyObject* args, PyObject* k
 	if (referTo < 0 || referTo > 2)
 	{
 		QString message = QObject::tr("refer_to=0|1|2.","python error");
-		PyErr_SetString(ScribusException, message.toLocal8Bit().constData());
+		PyErr_SetString(ScribusException, message.toUtf8().constData());
 		return nullptr;
 	}
 	else if (referTo == 2)
@@ -561,7 +567,7 @@ PyObject *scribus_setRowGuides(PyObject* /* self */, PyObject* args, PyObject* k
 		{
 			// refertTo a selection is only active, when there is a selection in the document
 			QString message = QObject::tr("setRowGuides() with refer_to=2 needs a selection.","python error");
-			PyErr_SetString(ScribusException, message.toLocal8Bit().constData());
+			PyErr_SetString(ScribusException, message.toUtf8().constData());
 			return nullptr;
 		}
 		doc->currentPage()->guides.resetSelectionForPage(doc->currentPage());
@@ -662,7 +668,7 @@ PyObject *scribus_importpage(PyObject* /* self */, PyObject* args)
 
 	if (!PyTuple_Check(pages))
 	{
-		PyErr_SetString(PyExc_TypeError, QObject::tr("second argument is not tuple: must be tuple of integer values.","python error").toLocal8Bit().constData());
+		PyErr_SetString(PyExc_TypeError, QObject::tr("second argument is not tuple: must be tuple of integer values.","python error").toUtf8().constData());
 		return nullptr;
 	}
 	Py_INCREF(pages);
@@ -674,7 +680,7 @@ PyObject *scribus_importpage(PyObject* /* self */, PyObject* args)
 	{
 		if (!PyArg_Parse(PyTuple_GetItem(pages, i), "i", &p))
 		{
-			PyErr_SetString(PyExc_TypeError, QObject::tr("second argument contains non-numeric values: must be list of integer values.","python error").toLocal8Bit().constData());
+			PyErr_SetString(PyExc_TypeError, QObject::tr("second argument contains non-numeric values: must be list of integer values.","python error").toUtf8().constData());
 			Py_DECREF(pages);
 			return nullptr;
 		}
